@@ -7,25 +7,24 @@
 #define OPENBLAS_PTHREAD_CREATE_FUNC pthread_create
 #define OPENBLAS_BUNDERSCORE _
 #define OPENBLAS_NEEDBUNDERSCORE 1
-#define OPENBLAS_CORTEXA57 
-#define OPENBLAS_HAVE_VFP 
-#define OPENBLAS_HAVE_VFPV3 
+#define OPENBLAS_ARMV8 
 #define OPENBLAS_HAVE_NEON 
 #define OPENBLAS_HAVE_VFPV4 
+#define OPENBLAS_CORTEXA57 
 #define OPENBLAS_L1_CODE_SIZE 49152
 #define OPENBLAS_L1_CODE_LINESIZE 64
 #define OPENBLAS_L1_CODE_ASSOCIATIVE 3
 #define OPENBLAS_L1_DATA_SIZE 32768
 #define OPENBLAS_L1_DATA_LINESIZE 64
 #define OPENBLAS_L1_DATA_ASSOCIATIVE 2
-#define OPENBLAS_L2_SIZE 2097152
+#define OPENBLAS_L2_SIZE 524288
 #define OPENBLAS_L2_LINESIZE 64
 #define OPENBLAS_L2_ASSOCIATIVE 16
 #define OPENBLAS_DTB_DEFAULT_ENTRIES 64
 #define OPENBLAS_DTB_SIZE 4096
 #define OPENBLAS_CHAR_CORENAME "CORTEXA57"
 #define OPENBLAS_GEMM_MULTITHREAD_THRESHOLD 4
-#define OPENBLAS_VERSION " OpenBLAS 0.3.3 "
+#define OPENBLAS_VERSION " OpenBLAS 0.3.4 "
 /*This is only for "make install" target.*/
 
 #if defined(OPENBLAS_OS_WINNT) || defined(OPENBLAS_OS_CYGWIN_NT) || defined(OPENBLAS_OS_INTERIX)
